@@ -2,7 +2,7 @@ package Spreadsheet::WriteExcel::FromDB;
 
 use strict;
 use vars qw/$VERSION/;
-$VERSION = 0.03;
+$VERSION = 0.04;
 
 use Spreadsheet::WriteExcel::Simple 0.02;
 
@@ -31,10 +31,10 @@ The data is not returned in any particular order, as it is a simple
 task to perform this in Excel. However, you may choose to ignore certain
 columns, using the 'ignore_columns' method.
 
-This relies on us knowing how to access the table information for this
-database. This is done by delegating the call 'columns_in_table' to
-an appropriate subclass. (At the moment this only exists for MySQL and
-Sybase, but please send me more!)
+This relies on us knowing how to access the table information for
+this database. This is done by delegating the call 'columns_in_table'
+to an appropriate subclass. (At the moment this only exists for MySQL,
+PostgreSQL and Sybase, but please send me more!)
 
 =head1 METHODS
 
